Coverage report

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
src/typedal/__about__.py | 1 | 0 | 0 | 100%
src/typedal/__init__.py | 5 | 0 | 2 | 100%
src/typedal/caching.py | 127 | 0 | 3 | 100%
src/typedal/cli.py | 65 | 0 | 85 | 100%
src/typedal/config.py | 135 | 0 | 11 | 100%
src/typedal/core.py | 903 | 0 | 144 | 100%
src/typedal/fields.py | 85 | 0 | 0 | 100%
src/typedal/for_py4web.py | 27 | 0 | 12 | 100%
src/typedal/helpers.py | 79 | 0 | 0 | 100%
src/typedal/serializers/as_json.py | 19 | 0 | 0 | 100%
src/typedal/types.py | 63 | 0 | 0 | 100%
Total | 1509 | 0 | 257 | 100%

No items found using the specified filter.